@@ -67,11 +67,6 @@ AppMenuView::~AppMenuView() {
     }
 }
 
-// To avoid incompatible cast to GDestroyNotify:
-static inline void menu_cache_item_unref0(MenuCacheItem* item) {
-    menu_cache_item_unref(item);
-}
-
 void AppMenuView::addMenuItems(QStandardItem* parentItem, MenuCacheDir* dir) {
     GSList* l;
     GSList* list;
@@ -100,7 +95,7 @@ void AppMenuView::addMenuItems(QStandardItem* parentItem, MenuCacheDir* dir) {
         }
         }
     }
-    g_slist_free_full(list, (GDestroyNotify)menu_cache_item_unref0);
+    g_slist_free_full(list, (GDestroyNotify)menu_cache_item_unref);
 }
 
 void AppMenuView::onMenuCacheReload(MenuCache* mc) {
