@@ -37,16 +37,9 @@ void FileTransferJob::setDestDirPath(const FilePath& destDirPath) {
     destPaths_.reserve(srcPaths_.size());
     for(const auto& srcPath: srcPaths_) {
         FilePath destPath;
-        if(!srcPath.isNative()) {
+        if(mode_ == Mode::LINK && !srcPath.isNative()) {
             // special handling for URLs
             auto fullBasename = srcPath.baseName();
-            if(g_strcmp0(fullBasename.get(), "/") == 0) { // happens when URI ends with slash
-                auto fullParseName = srcPath.displayName();
-                char* parseName = fullParseName.get();
-                parseName[strlen(parseName)-1] = 0;
-                auto path = FilePath::fromDisplayName(parseName);
-                fullBasename = path.baseName();
-            }
             char* basename = fullBasename.get();
             char* dname = nullptr;
             // if we drop URI query onto native filesystem, omit query part
@@ -121,7 +114,7 @@ bool FileTransferJob::copyRegularFile(const FilePath& srcPath, const GFileInfoPt
         err.reset();
 
         // reset progress of the current file (only for copy)
-        auto size = g_file_info_get_attribute_uint64(srcInfo.get(), G_FILE_ATTRIBUTE_STANDARD_SIZE);
+        auto size = g_file_info_get_size(srcInfo.get());
         setCurrentFileProgress(size, 0);
 
         // do the file operation
@@ -447,13 +440,7 @@ bool FileTransferJob::moveFile(const FilePath &srcPath, const GFileInfoPtr &srcI
     auto src_fs = g_file_info_get_attribute_string(srcInfo.get(), "id::filesystem");
     auto dest_fs = g_file_info_get_attribute_string(destDirInfo.get(), "id::filesystem");
     bool ret;
-    if(src_fs && dest_fs
-       && (g_str_has_prefix(src_fs, "trash")
-           || (strcmp(src_fs, dest_fs) == 0
-               // NOTE: GLib does not allow moving a directory over another one with the
-               // same name. As a workaround, also do copy & delete in this case.
-               && !(g_file_info_get_file_type(srcInfo.get()) == G_FILE_TYPE_DIRECTORY
-                    && g_strcmp0(srcPath.baseName().get(), destFileName) == 0)))) {
+    if(src_fs && dest_fs && (strcmp(src_fs, dest_fs) == 0 || g_str_has_prefix(src_fs, "trash"))) {
         // src and dest are on the same filesystem
         auto destPath = destDirPath.child(destFileName);
         ret = moveFileSameFs(srcPath, srcInfo, destPath);
@@ -461,7 +448,7 @@ bool FileTransferJob::moveFile(const FilePath &srcPath, const GFileInfoPtr &srcI
         // increase current progress
         // FIXME: it's not appropriate to calculate the progress of move operations using file size
         // since the time required to move a file is not related to it's file size.
-        auto size = g_file_info_get_attribute_uint64(srcInfo.get(), G_FILE_ATTRIBUTE_STANDARD_SIZE);
+        auto size = g_file_info_get_size(srcInfo.get());
         addFinishedAmount(size, 1);
     }
     else {
@@ -475,7 +462,7 @@ bool FileTransferJob::moveFile(const FilePath &srcPath, const GFileInfoPtr &srcI
 bool FileTransferJob::copyFile(const FilePath& srcPath, const GFileInfoPtr& srcInfo, const FilePath& destDirPath, const char* destFileName, bool skip) {
     setCurrentFile(srcPath);
 
-    auto size = g_file_info_get_attribute_uint64(srcInfo.get(), G_FILE_ATTRIBUTE_STANDARD_SIZE);
+    auto size = g_file_info_get_size(srcInfo.get());
     bool success = false;
     setCurrentFileProgress(size, 0);
 
@@ -614,15 +601,8 @@ bool FileTransferJob::createShortcut(const FilePath &srcPath, const GFileInfoPtr
 
     CStrPtr srcPathDispName;
     auto name = g_file_info_get_display_name(srcInfo.get());
-    if(!name || g_strcmp0(name, "/") == 0) {
-        srcPathDispName = srcPath.baseName();
-        if(g_strcmp0(srcPathDispName.get(), "/") == 0) { // happens when URI ends with slash
-            auto fullParseName = srcPath.displayName();
-            char* parseName = fullParseName.get();
-            parseName[strlen(parseName)-1] = 0;
-            auto path = FilePath::fromDisplayName(parseName);
-            srcPathDispName = path.baseName();
-        }
+    if(!name) {
+        srcPathDispName = srcPath.displayName();
         name = srcPathDispName.get();
     }
 
