@@ -19,39 +19,27 @@ static void child_setup(gpointer user_data) {
 }
 
 bool launchTerminal(const char* programName, const FilePath& workingDir, Fm::GErrorPtr& error) {
-    CStrPtr desktop_id;
-    CStrPtr launch;
-    CStrPtr custom_args;
-
-    /* read local and global terminals lists */
+    /* read user and system terminals files */
     GKeyFile* kf = g_key_file_new();
-    if(g_key_file_load_from_data_dirs(kf, "libfm-qt/terminals.list", nullptr, G_KEY_FILE_NONE, nullptr)
-       && g_key_file_has_group(kf, programName)) {
-        desktop_id = CStrPtr{g_key_file_get_string(kf, programName, "desktop_id", nullptr)};
-        launch = CStrPtr{g_key_file_get_string(kf, programName, "launch", nullptr)};
-        /* read only from the local list */
-        custom_args = CStrPtr{g_key_file_get_string(kf, programName, "custom_args", nullptr)};
+    bool found = g_key_file_load_from_data_dirs(kf, "libfm-qt/terminals.list", nullptr, G_KEY_FILE_NONE, &error);
+    if(found) {
+        found = g_key_file_has_group(kf, programName);
     }
-    if (!desktop_id || !launch // file or key did not exist
-        // value did not exist
-        || g_strcmp0(desktop_id.get(), "") == 0 || g_strcmp0(launch.get(), "") == 0) {
+    if(!found) {
         g_key_file_free(kf);
         kf = g_key_file_new();
-        if(g_key_file_load_from_file(kf, LIBFM_QT_DATA_DIR "/terminals.list", G_KEY_FILE_NONE, &error)
-           && g_key_file_has_group(kf, programName)) {
-            if (!desktop_id || g_strcmp0(desktop_id.get(), "") == 0) {
-                desktop_id = CStrPtr{g_key_file_get_string(kf, programName, "desktop_id", nullptr)};
-            }
-            if (!launch || g_strcmp0(launch.get(), "") == 0) {
-                launch = CStrPtr{g_key_file_get_string(kf, programName, "launch", nullptr)};
-            }
+        if(!g_key_file_load_from_file(kf, LIBFM_QT_DATA_DIR "/terminals.list", G_KEY_FILE_NONE, &error)) {
+            g_key_file_free(kf);
+            return false;
         }
     }
-    g_key_file_free(kf);
+
+    auto launch = g_key_file_get_string(kf, programName, "launch", nullptr);
+    auto desktop_id = g_key_file_get_string(kf, programName, "desktop_id", nullptr);
 
     GDesktopAppInfo* appinfo = nullptr;
-    if(desktop_id && g_strcmp0(desktop_id.get(), "") != 0) {
-        appinfo = g_desktop_app_info_new(desktop_id.get());
+    if(desktop_id) {
+        appinfo = g_desktop_app_info_new(desktop_id);
     }
 
     const gchar* cmd;
@@ -59,18 +47,20 @@ bool launchTerminal(const char* programName, const FilePath& workingDir, Fm::GEr
     if(appinfo) {
         cmd = g_app_info_get_commandline(G_APP_INFO(appinfo));
     }
-    else if(launch && g_strcmp0(launch.get(), "") != 0) {
-        cmd = _cmd = g_strdup_printf("%s %s", programName, launch.get());
+    else if(launch) {
+        cmd = _cmd = g_strdup_printf("%s %s", programName, launch);
     }
     else {
         cmd = programName;
     }
 
-    if(custom_args && g_strcmp0(custom_args.get(), "") != 0) {
-        cmd = g_strdup_printf("%s %s", cmd, custom_args.get());
+#if 0 // FIXME: what's this?
+    if(custom_args) {
+        cmd = g_strdup_printf("%s %s", cmd, custom_args);
         g_free(_cmd);
         _cmd = (char*)cmd;
     }
+#endif
 
     char** argv;
     int argc;
@@ -125,23 +115,8 @@ bool launchTerminal(const char* programName, const FilePath& workingDir, Fm::GEr
                              nullptr, &error);
     g_strfreev(argv);
     g_strfreev(envp);
-    return ret;
-}
-
-std::vector<CStrPtr> internalTerminals() {
-    std::vector<CStrPtr> terminals;
-    GKeyFile* kf = g_key_file_new();
-    if(g_key_file_load_from_file(kf, LIBFM_QT_DATA_DIR "/terminals.list", G_KEY_FILE_NONE, nullptr)) {
-        gsize n;
-        auto programs = g_key_file_get_groups(kf, &n);
-        terminals.reserve(terminals.capacity() + n);
-        for(auto name = programs; *name; ++name) {
-            terminals.emplace_back(*name);
-        }
-        g_free(programs);
-    }
     g_key_file_free(kf);
-    return terminals;
+    return ret;
 }
 
 std::vector<CStrPtr> allKnownTerminals() {
@@ -182,38 +157,28 @@ extern "C" char* expand_terminal(char* cmd, gboolean keep_open, GError** error)
     CStrPtr noclose_arg;
     CStrPtr custom_args;
 
-    /* read local and global terminals lists */
+    /* read user and system terminals files */
+    bool found = false;
     GKeyFile* kf = g_key_file_new();
-    if(g_key_file_load_from_data_dirs(kf, "libfm-qt/terminals.list", nullptr, G_KEY_FILE_NONE, nullptr)
-       && g_key_file_has_group(kf, defaultTerminalName.c_str())) {
+    if(g_key_file_load_from_data_dirs(kf, "libfm-qt/terminals.list", nullptr, G_KEY_FILE_NONE, error)) {
+        found = g_key_file_has_group(kf, defaultTerminalName.c_str());
+    }
+    if(!found) {
+        g_key_file_free(kf);
+        kf = g_key_file_new();
+        if(g_key_file_load_from_file(kf, LIBFM_QT_DATA_DIR "/terminals.list", G_KEY_FILE_NONE, error)) {
+            found = g_key_file_has_group(kf, defaultTerminalName.c_str());
+        }
+    }
+    if(found) {
         program = defaultTerminalName.c_str();
         open_arg = CStrPtr{g_key_file_get_string(kf, program, "open_arg", nullptr)};
         noclose_arg = CStrPtr{g_key_file_get_string(kf, program, "noclose_arg", nullptr)};
         custom_args = CStrPtr{g_key_file_get_string(kf, program, "custom_args", nullptr)};
-        /* NOTE: "custom_args" is read only from the local list, but if "open_arg" or
-           "noclose_arg" is missing in the local list, it will be read from the global list. */
-    }
-    if(!open_arg || !noclose_arg // file or key did not exist
-       // value did not exist
-       || g_strcmp0(open_arg.get(), "") == 0 || g_strcmp0(noclose_arg.get(), "") == 0) {
-        g_key_file_free(kf);
-        kf = g_key_file_new();
-        if(g_key_file_load_from_file(kf, LIBFM_QT_DATA_DIR "/terminals.list", G_KEY_FILE_NONE, error)
-           && g_key_file_has_group(kf, defaultTerminalName.c_str())) {
-            if(!program) {
-                program = defaultTerminalName.c_str();
-            }
-            if(!open_arg || g_strcmp0(open_arg.get(), "") == 0) {
-                open_arg = CStrPtr{g_key_file_get_string(kf, program, "open_arg", nullptr)};
-            }
-            if(!noclose_arg || g_strcmp0(noclose_arg.get(), "") == 0) {
-                noclose_arg = CStrPtr{g_key_file_get_string(kf, program, "noclose_arg", nullptr)};
-            }
-        }
     }
     g_key_file_free(kf);
 
-    const char* opts = nullptr;
+    const char* opts;
     /* if %s is not found, fallback to -e */
     /* bug #3457335: Crash on application start with Terminal=true. */
     /* fallback to xterm if a terminal emulator is not found. */
@@ -225,9 +190,9 @@ extern "C" char* expand_terminal(char* cmd, gboolean keep_open, GError** error)
         open_arg = CStrPtr{g_strdup("-e")};
     }
 
-    if(keep_open && noclose_arg && g_strcmp0(noclose_arg.get(), "") != 0)
+    if(keep_open && noclose_arg)
         opts = noclose_arg.get();
-    else if (open_arg && g_strcmp0(open_arg.get(), "") != 0)
+    else
         opts = open_arg.get();
 
     if(!opts) {
@@ -236,7 +201,7 @@ extern "C" char* expand_terminal(char* cmd, gboolean keep_open, GError** error)
     }
 
     char* ret = nullptr;
-    if(custom_args && g_strcmp0(custom_args.get(), "") != 0)
+    if(custom_args)
         ret = g_strdup_printf("%s %s %s %s", program, custom_args.get(),
                               opts, cmd);
     else
