@@ -17,10 +17,9 @@ bool ThumbnailJob::localFilesOnly_ = true;
 int ThumbnailJob::maxThumbnailFileSize_ = 4096; // in KiB
 int ThumbnailJob::maxExternalThumbnailFileSize_ = -1;
 
-ThumbnailJob::ThumbnailJob(FileInfoList files, int size, bool isRemote):
+ThumbnailJob::ThumbnailJob(FileInfoList files, int size):
     files_{std::move(files)},
     size_{size},
-    isRemote_{isRemote},
     md5Calc_{g_checksum_new(G_CHECKSUM_MD5)} {
 }
 
@@ -67,16 +66,12 @@ QImage ThumbnailJob::loadForFile(const std::shared_ptr<const FileInfo> &file) {
         return QImage();
     }
 
-    if(localFilesOnly_ && isRemote_) {
-        return QImage();
-    }
-
     // thumbnails are stored in $XDG_CACHE_HOME/thumbnails/large|normal|failed
     QString thumbnailDir{QString::fromUtf8(g_get_user_cache_dir())};
     thumbnailDir += QLatin1String("/thumbnails/");
 
     // don't make thumbnails for files inside the thumbnail directory
-    if(file->dirPath() && FilePath::fromLocalPath(thumbnailDir.toLocal8Bit().constData()).isParentOf(file->dirPath())) {
+    if(FilePath::fromLocalPath(thumbnailDir.toLocal8Bit().constData()).isParentOf(file->dirPath())) {
         return QImage();
     }
 
@@ -93,14 +88,7 @@ QImage ThumbnailJob::loadForFile(const std::shared_ptr<const FileInfo> &file) {
         // if the file is changed to a symlink with the same time stamp
         auto target = file->target();
         if(!target.empty()) {
-            if(file->dirPath()) {
-                // "FilePath::relativePath()" also covers absolute path names
-                // because "g_file_resolve_relative_path()" does
-                uri = file->dirPath().relativePath(target.c_str()).uri();
-            }
-            else {
-                uri = FilePath::fromLocalPath(target.c_str()).uri();
-            }
+            uri = FilePath::fromLocalPath(target.c_str()).uri();
         }
     }
     if(!uri) {
