@@ -14,16 +14,11 @@
 #include <QMimeDatabase>
 #include <QMessageBox>
 #include <QToolBar>
-#include <QActionGroup>
 #include <QCompleter>
 #include <QShortcut>
 #include <QTimer>
 #include <QDebug>
 
-#include <algorithm>
-
-using namespace Qt::Literals::StringLiterals;
-
 namespace Fm {
 
 
@@ -87,12 +82,7 @@ FileDialog::FileDialog(QWidget* parent, FilePath path) :
                 name += QLatin1Char('.');
                 name += defaultSuffix_;
             }
-            if(name.contains(QLatin1Char('/'))) {
-                selectFilePath(Fm::FilePath::fromPathStr(name.toLocal8Bit().constData()));
-            }
-            else {
-                selectFilePath(directoryPath_.child(name.toLocal8Bit().constData()));
-            }
+            selectFilePath(directoryPath_.child(name.toLocal8Bit().constData()));
         }
         updateAcceptButtonState();
         updateSaveButtonText(false);
@@ -105,21 +95,21 @@ FileDialog::FileDialog(QWidget* parent, FilePath path) :
     connect(ui->fileTypeCombo, &QComboBox::currentTextChanged, [this](const QString& text) {
         selectNameFilter(text);
     });
-    ui->fileTypeCombo->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);
+    ui->fileTypeCombo->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLength);
     ui->fileTypeCombo->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
     ui->fileTypeCombo->setCurrentIndex(0);
 
     // setup toolbar buttons
     auto toolbar = new QToolBar(this);
     // back button
-    backAction_ = toolbar->addAction(QIcon::fromTheme(u"go-previous"_s), tr("Go Back"));
+    backAction_ = toolbar->addAction(QIcon::fromTheme(QStringLiteral("go-previous")), tr("Go Back"));
     backAction_->setShortcut(QKeySequence(tr("Alt+Left", "Go Back")));
     connect(backAction_, &QAction::triggered, [this]() {
         history_.backward();
         setDirectoryPath(history_.currentPath(), FilePath(), false);
     });
     // forward button
-    forwardAction_ = toolbar->addAction(QIcon::fromTheme(u"go-next"_s), tr("Go Forward"));
+    forwardAction_ = toolbar->addAction(QIcon::fromTheme(QStringLiteral("go-next")), tr("Go Forward"));
     forwardAction_->setShortcut(QKeySequence(tr("Alt+Right", "Go Forward")));
     connect(forwardAction_, &QAction::triggered, [this]() {
         history_.forward();
@@ -127,7 +117,7 @@ FileDialog::FileDialog(QWidget* parent, FilePath path) :
     });
     toolbar->addSeparator();
     // reload button
-    auto reloadAction = toolbar->addAction(QIcon::fromTheme(u"view-refresh"_s), tr("Reload"));
+    auto reloadAction = toolbar->addAction(QIcon::fromTheme(QStringLiteral("view-refresh")), tr("Reload"));
     reloadAction->setShortcut(QKeySequence(tr("F5", "Reload")));
     connect(reloadAction, &QAction::triggered, [this]() {
         if(folder_ && folder_->isLoaded()) {
@@ -145,12 +135,12 @@ FileDialog::FileDialog(QWidget* parent, FilePath path) :
         }
     });
     // new folder button
-    auto newFolderAction = toolbar->addAction(QIcon::fromTheme(u"folder-new"_s), tr("Create Folder"));
+    auto newFolderAction = toolbar->addAction(QIcon::fromTheme(QStringLiteral("folder-new")), tr("Create Folder"));
     connect(newFolderAction, &QAction::triggered, this, &FileDialog::onNewFolder);
     toolbar->addSeparator();
 
     // a shortcut for deselecting all items
-    QShortcut* shortcut = new QShortcut(QKeySequence(Qt::CTRL | Qt::Key_D), this);
+    QShortcut* shortcut = new QShortcut(QKeySequence(Qt::CTRL + Qt::Key_D), this);
     connect(shortcut, &QShortcut::activated, [this]() {
         ui->folderView->selectionModel()->clearSelection();
     });
@@ -161,19 +151,19 @@ FileDialog::FileDialog(QWidget* parent, FilePath path) :
     // view actions
     auto viewModeGroup = new QActionGroup(this);
     // use generic icons for view actions only if theme icons don't exist
-    iconViewAction_ = menu->addAction(QIcon::fromTheme(u"view-list-icons"_s, style()->standardIcon(QStyle::SP_FileDialogContentsView)), tr("Icon View"));
+    iconViewAction_ = menu->addAction(QIcon::fromTheme(QLatin1String("view-list-icons"), style()->standardIcon(QStyle::SP_FileDialogContentsView)), tr("Icon View"));
     iconViewAction_->setCheckable(true);
     connect(iconViewAction_, &QAction::toggled, this, &FileDialog::onViewModeToggled);
     viewModeGroup->addAction(iconViewAction_);
-    thumbnailViewAction_ = menu->addAction(QIcon::fromTheme(u"view-preview"_s, style()->standardIcon(QStyle::SP_FileDialogInfoView)), tr("Thumbnail View"));
+    thumbnailViewAction_ = menu->addAction(QIcon::fromTheme(QLatin1String("view-preview"), style()->standardIcon(QStyle::SP_FileDialogInfoView)), tr("Thumbnail View"));
     thumbnailViewAction_->setCheckable(true);
     connect(thumbnailViewAction_, &QAction::toggled, this, &FileDialog::onViewModeToggled);
     viewModeGroup->addAction(thumbnailViewAction_);
-    compactViewAction_ = menu->addAction(QIcon::fromTheme(u"view-list-text"_s, style()->standardIcon(QStyle::SP_FileDialogListView)), tr("Compact View"));
+    compactViewAction_ = menu->addAction(QIcon::fromTheme(QLatin1String("view-list-text"), style()->standardIcon(QStyle::SP_FileDialogListView)), tr("Compact View"));
     compactViewAction_->setCheckable(true);
     connect(compactViewAction_, &QAction::toggled, this, &FileDialog::onViewModeToggled);
     viewModeGroup->addAction(compactViewAction_);
-    detailedViewAction_ = menu->addAction(QIcon::fromTheme(u"view-list-details"_s, style()->standardIcon(QStyle::SP_FileDialogDetailedView)), tr("Detailed List View"));
+    detailedViewAction_ = menu->addAction(QIcon::fromTheme(QLatin1String("view-list-details"), style()->standardIcon(QStyle::SP_FileDialogDetailedView)), tr("Detailed List View"));
     detailedViewAction_->setCheckable(true);
     connect(detailedViewAction_, &QAction::toggled, this, &FileDialog::onViewModeToggled);
     viewModeGroup->addAction(detailedViewAction_);
@@ -219,7 +209,7 @@ FileDialog::FileDialog(QWidget* parent, FilePath path) :
         proxyModel_->setShowHidden(checked);
     });
     // also add a separate shortcut for it
-    shortcut = new QShortcut(QKeySequence(Qt::CTRL | Qt::Key_H), this);
+    shortcut = new QShortcut(QKeySequence(Qt::CTRL + Qt::Key_H), this);
     connect(shortcut, &QShortcut::activated, [this]() {
         proxyModel_->setShowHidden(!proxyModel_->showHidden());
     });
@@ -252,7 +242,7 @@ FileDialog::FileDialog(QWidget* parent, FilePath path) :
     });
 
     // Options menu button
-    auto optionsAction = toolbar->addAction(QIcon::fromTheme(u"preferences-system"_s, QIcon::fromTheme(u"document-properties"_s)), tr("Options"));
+    auto optionsAction = toolbar->addAction(QIcon::fromTheme(QStringLiteral("preferences-system"), QIcon::fromTheme(QStringLiteral("document-properties"))), tr("Options"));
     optionsAction->setMenu(menu);
     // change the popup mode to instant (Qt sets it to MenuButtonPopup)
     if(QToolButton* optionsBtn = static_cast<QToolButton*>(toolbar->widgetForAction(optionsAction))) {
@@ -335,7 +325,7 @@ int FileDialog::splitterPos() const {
 
 void FileDialog::setSplitterPos(int pos) {
     QList<int> sizes;
-    sizes.append(std::max(pos, 0));
+    sizes.append(qMax(pos, 0));
     sizes.append(320);
     ui->splitter->setSizes(sizes);
 }
@@ -512,12 +502,12 @@ QStringList FileDialog::parseNames() const {
            && (firstQuote == 0 || fileNames.at(firstQuote - 1) != QLatin1Char('\\'))
            && fileNames.at(lastQuote - 1) != QLatin1Char('\\')) {
            // split the names
-            QRegularExpression sep{u"\"\\s+\""_s};  // separated with " "
+            QRegularExpression sep{QStringLiteral("\"\\s+\"")};  // separated with " "
             parsedNames = fileNames.mid(firstQuote + 1, lastQuote - firstQuote - 1).split(sep);
-            parsedNames.replaceInStrings(u"\\\""_s, u"\""_s);
+            parsedNames.replaceInStrings(QLatin1String("\\\""), QLatin1String("\""));
         }
         else {
-            parsedNames << fileNames.replace("\\\""_L1, "\""_L1);
+            parsedNames << fileNames.replace(QLatin1String("\\\""), QLatin1String("\""));
         }
     }
     return parsedNames;
@@ -552,7 +542,7 @@ QString FileDialog::suffix(bool checkDefaultSuffix) const {
                 left = suffix.indexOf(QLatin1Char('.')); // it can be like ".tar.xz"
                 if(left != -1 && suffix.size() - left > 1) {
                     suffix = suffix.right(suffix.size() - left - 1);
-                    if(suffix.indexOf(QRegularExpression(u"[^\\w\\.]"_s)) == -1) {
+                    if(suffix.indexOf(QRegularExpression(QStringLiteral("[^\\w\\.]"))) == -1) {
                         return suffix;
                     }
                 }
@@ -620,57 +610,23 @@ void FileDialog::accept() {
                 _suffix = suffix();
                 suffixFound = true;
             }
-            Fm::FilePath firstPath;
-            bool exists = false;
-            bool isDir = false;
             // don't consider the suffix yet because a directory with the same name may exist
-            if(firstName.contains(QLatin1Char('/'))) {
-                // "FilePath::relativePath()" also covers absolute path names
-                // because "g_file_resolve_relative_path()" does
-                firstPath = directoryPath_.relativePath(firstName.toLocal8Bit().constData());
-                auto str = QString::fromUtf8(firstPath.toString().get());
-                if(QFileInfo::exists(str)) {
-                    exists = true;
-                    isDir = QFileInfo(str).isDir();
-                }
-            }
-            else {
-                firstPath = directoryPath_.child(firstName.toLocal8Bit().constData());
-                auto info = folderModel_->fileInfoFromPath(firstPath);
-                if(info != nullptr) {
-                    exists = true;
-                    isDir = info->isDir();
-                }
-            }
-            if(isDir) {
+            auto childPath = directoryPath_.child(firstName.toLocal8Bit().constData());
+            auto info = folderModel_->fileInfoFromPath(childPath);
+            if(info && info->isDir()) {
                 // if the typed name belongs to a (nonselected) directory, chdir into it
-                setDirectoryPath(firstPath);
+                setDirectoryPath(childPath);
                 return;
             }
             if(!_suffix.isEmpty()) {
-                exists = false;
                 firstName += QLatin1Char('.');
                 firstName += _suffix;
-                if(firstName.contains(QLatin1Char('/'))) {
-                    firstPath = directoryPath_.relativePath(firstName.toLocal8Bit().constData());
-                    auto str = QString::fromUtf8(firstPath.toString().get());
-                    if(QFileInfo::exists(str)) {
-                        exists = true;
-                        isDir = QFileInfo(str).isDir();
-                    }
-                }
-                else {
-                    firstPath = directoryPath_.child(firstName.toLocal8Bit().constData());
-                    auto info = folderModel_->fileInfoFromPath(firstPath);
-                    if(info != nullptr) {
-                        exists = true;
-                        isDir = info->isDir();
-                    }
-                }
+                childPath = directoryPath_.child(firstName.toLocal8Bit().constData());
+                info = folderModel_->fileInfoFromPath(childPath);
             }
-            if(exists) {
-                if(isDir) {
-                    setDirectoryPath(firstPath);
+            if(info) {
+                if(info->isDir()) {
+                    setDirectoryPath(childPath);
                     return;
                 }
                 // overwrite prompt (as in QFileDialog::accept)
@@ -701,13 +657,7 @@ void FileDialog::accept() {
                     name += _suffix;
                 }
             }
-            Fm::FilePath fullPath;
-            if(name.contains(QLatin1Char('/'))) {
-                fullPath = directoryPath_.relativePath(name.toLocal8Bit().constData());
-            }
-            else {
-                fullPath = directoryPath_.child(name.toLocal8Bit().constData());
-            }
+            auto fullPath = directoryPath_.child(name.toLocal8Bit().constData());
             auto localPath = fullPath.localPath();
             /* add the local path if it exists; otherwise, add the uri */
             if(localPath) {
@@ -803,18 +753,8 @@ void FileDialog::setDirectoryPath(FilePath directory, FilePath selectedPath, boo
         }
     }
     else {
-        if(folder_ == nullptr || folder_->isLoaded()) {
-            updateAcceptButtonState();
-            updateSaveButtonText(false);
-        }
-        else {
-            lambdaConnection_ = QObject::connect(folder_.get(), &Fm::Folder::finishLoading, this, [this, selectedPath]() {
-                QTimer::singleShot(0, this, [this]() {
-                    updateAcceptButtonState();
-                    updateSaveButtonText(false);
-                });
-            });
-        }
+        updateAcceptButtonState();
+        updateSaveButtonText(false);
     }
 }
 
@@ -911,13 +851,13 @@ void FileDialog::onSelectionChanged(const QItemSelection& /*selected*/, const QI
             // escape inside quotes with \ to distinguish between them
             // and the quotes used for separating file names from each other
             QString name(QString::fromUtf8(baseName.get()));
-            fileNames += name.replace("\""_L1, "\\\""_L1);
+            fileNames += name.replace(QLatin1String("\""), QLatin1String("\\\""));
             fileNames += QLatin1Char('\"');
         }
         else {
             // support single selection only
             QString name(QString::fromUtf8(baseName.get()));
-            fileNames = name.replace("\""_L1, "\\\""_L1);
+            fileNames = name.replace(QLatin1String("\""), QLatin1String("\\\""));
             break;
         }
     }
@@ -1006,66 +946,50 @@ void FileDialog::onFileInfoJobFinished() {
         selectedFiles_.clear();
         reject();
     }
-    else if(fileMode_ == QFileDialog::AnyFile) {
-        doAccept(); // non-existent files are allowed
-    }
     else {
         QString error;
         // check if the files exist and their types are correct
-        // FIXME: currently, if a path is not found, FmFileInfoJob does not return its file info object.
-        // This may not be a bad API design. We may return nullptr for the failed file info query instead.
-        size_t fileIdx = 0;
-        int selIdx = 0;
         auto paths = job->paths();
         auto files = job->files();
         for(size_t i = 0; i < paths.size(); ++i) {
             const auto& path = paths[i];
-            if(fileIdx >= files.size() || files[fileIdx]->path() != path) {
+            if(i >= files.size() || files[i]->path() != path) {
                 // the file path is not found and does not have file info
-                if(error.isEmpty()) {
+                if(fileMode_ != QFileDialog::AnyFile) {
+                    // if we do not allow non-existent file, this is an error.
                     error = tr("Path \"%1\" does not exist").arg(QString::fromUtf8(path.displayName().get()));
+                    break;
                 }
-                if(selIdx < selectedFiles_.size()) {
-                    selectedFiles_.removeAt(selIdx);
-                }
-                continue; // skip the file
+                ++i; // skip the file
+                continue;
             }
 
-            const auto& file = files[fileIdx];
+            // FIXME: currently, if a path is not found, FmFileInfoJob does not return its file info object.
+            // This is bad API design. We may return nullptr for the failed file info query instead.
+            const auto& file = files[i];
             // check if the file type is correct
             if(fileMode_ == QFileDialog::Directory) {
                 if(!file->isDir()) {
-                    if(error.isEmpty()) {
-                        // we're selecting dirs, but the selected file path does not point to a dir
-                        error = tr("\"%1\" is not a directory").arg(QString::fromUtf8(path.displayName().get()));
-                    }
-                    if(selIdx < selectedFiles_.size()) {
-                        selectedFiles_.removeAt(selIdx);
-                    }
+                    // we're selecting dirs, but the selected file path does not point to a dir
+                    error = tr("\"%1\" is not a directory").arg(QString::fromUtf8(path.displayName().get()));
+                    break;
                 }
             }
             else if(file->isDir() || (file->isShortcut() && !file->isDesktopEntry())) {
-                if(error.isEmpty()) {
-                    // we're selecting files, but the selected file path refers to a dir or shortcut (such as computer:///)
-                    error = tr("\"%1\" is not a file").arg(QString::fromUtf8(path.displayName().get()));
-                }
-                if(selIdx < selectedFiles_.size()) {
-                    selectedFiles_.removeAt(selIdx);
-                }
+                // we're selecting files, but the selected file path refers to a dir or shortcut (such as computer:///)
+                error = tr("\"%1\" is not a file").arg(QString::fromUtf8(path.displayName().get()));
+                break;
             }
-            else {
-                ++selIdx;
-            }
-
-            ++fileIdx;
         }
 
-        if(!error.isEmpty()) {
-            QMessageBox::critical(this, tr("Error"), error);
-        }
-        if(!selectedFiles_.isEmpty()) { // at least one file is accepted
+        if(error.isEmpty()) {
+            // no error!
             doAccept();
         }
+        else {
+            QMessageBox::critical(this, tr("Error"), error);
+            selectedFiles_.clear();
+        }
     }
     ui->buttonBox->button(QDialogButtonBox::Ok)->setEnabled(true);
 }
@@ -1187,6 +1111,10 @@ void FileDialog::setViewMode(FolderView::ViewMode mode) {
 
 
 void FileDialog::setFileMode(QFileDialog::FileMode mode) {
+    if(mode == QFileDialog::DirectoryOnly) {
+        // directly only is deprecated and not allowed.
+        mode = QFileDialog::Directory;
+    }
     fileMode_ = mode;
 
     // enable multiple selection?
@@ -1229,10 +1157,10 @@ void FileDialog::setMimeTypeFilters(const QStringList& filters) {
         auto mimeType = db.mimeTypeForName(filter);
         auto nameFilter = mimeType.comment();
         if(!mimeType.suffixes().empty()) {
-            nameFilter += " ("_L1;
+            nameFilter += QLatin1String(" (");
             const auto suffixes = mimeType.suffixes();
             for(const auto& suffix: suffixes) {
-                nameFilter += "*."_L1;
+                nameFilter += QLatin1String("*.");
                 nameFilter += suffix;
                 nameFilter += QLatin1Char(' ');
             }
@@ -1302,18 +1230,9 @@ void FileDialog::updateSaveButtonText(bool saveOnFolder) {
         if(!saveOnFolder) {
             QStringList parsedNames = parseNames();
             if(!parsedNames.isEmpty()) {
-                if(parsedNames.at(0).contains(QLatin1Char('/'))) {
-                    auto path = directoryPath_.relativePath(parsedNames.at(0).toLocal8Bit().constData());
-                    auto str = QString::fromUtf8(path.toString().get());
-                    if(QFileInfo::exists(str) && QFileInfo(str).isDir()) {
-                        saveOnFolder = true;
-                    }
-                }
-                else {
-                    auto info = proxyModel_->fileInfoFromPath(directoryPath_.child(parsedNames.at(0).toLocal8Bit().constData()));
-                    if(info && info->isDir()) {
-                        saveOnFolder = true;
-                    }
+                auto info = proxyModel_->fileInfoFromPath(directoryPath_.child(parsedNames.at(0).toLocal8Bit().constData()));
+                if(info && info->isDir()) {
+                    saveOnFolder = true;
                 }
             }
         }
@@ -1337,30 +1256,19 @@ void FileDialog::updateAcceptButtonState() {
     if(fileMode_ != QFileDialog::Directory) {
         if(acceptMode_ == QFileDialog::AcceptOpen)
         {
-            if(firstSelectedDir()
-               || (fileMode_ == QFileDialog::AnyFile && !ui->fileName->text().isEmpty())) {
-                // enable "open" button if a dir is selected or any file can be opened
+            if(firstSelectedDir()) {
+                // enable "open" button if a dir is selected
                 enable = true;
             }
             else {
-                // enable "open" button when there is a file whose name is listed
-                QStringList parsedNames = parseNames();
-                for(auto& name: parsedNames) {
-                    if(name.contains(QLatin1Char('/'))) {
-                        auto path = directoryPath_.relativePath(name.toLocal8Bit().constData());
-                        auto str = QString::fromUtf8(path.toString().get());
-                        if(QFileInfo::exists(str)) {
-                            enable = true;
-                            break;
-                        }
-                    }
-                    else {
-                        if(proxyModel_->indexFromPath(directoryPath_.child(name.toLocal8Bit().constData())).isValid()) {
-                            enable = true;
-                            break;
-                        }
-                    }
-                }
+              // enable "open" button when there is a file whose name is listed
+              QStringList parsedNames = parseNames();
+              for(auto& name: parsedNames) {
+                  if(proxyModel_->indexFromPath(directoryPath_.child(name.toLocal8Bit().constData())).isValid()) {
+                    enable = true;
+                    break;
+                  }
+              }
             }
         }
         else if(acceptMode_ == QFileDialog::AcceptSave) {
@@ -1383,21 +1291,11 @@ void FileDialog::updateAcceptButtonState() {
         }
         else {
             for(auto& name: parsedNames) {
-                if(name.contains(QLatin1Char('/'))) {
-                    auto path = directoryPath_.relativePath(name.toLocal8Bit().constData());
-                    auto str = QString::fromUtf8(path.toString().get());
-                    if(QFileInfo::exists(str) && QFileInfo(str).isDir()) {
-                        enable = true;
-                        break;
-                    }
-                }
-                else {
-                    auto info = proxyModel_->fileInfoFromPath(directoryPath_.child(name.toLocal8Bit().constData()));
-                    if(info && info->isDir()) {
-                        // the name of a dir is listed
-                        enable = true;
-                        break;
-                    }
+                auto info = proxyModel_->fileInfoFromPath(directoryPath_.child(name.toLocal8Bit().constData()));
+                if(info && info->isDir()) {
+                    // the name of a dir is listed
+                    enable = true;
+                    break;
                 }
             }
         }
@@ -1424,7 +1322,7 @@ bool FileDialog::FileDialogFilter::filterAcceptsRow(const ProxyFolderModel* /*mo
     }
 
     bool nameMatched = false;
-    auto& name = (!info->name().empty() ? QString::fromStdString(info->name()) : info->displayName());
+    auto& name = info->displayName();
     for(const auto& pattern: patterns_) {
         if(name.indexOf(pattern) == 0) {
             nameMatched = true;
