@@ -30,7 +30,6 @@
 #include <QFileDialog>
 #include <sys/types.h>
 #include <ctime>
-#include <cmath>
 #include "core/totalsizejob.h"
 #include "core/folder.h"
 
@@ -40,8 +39,6 @@
 #define DIFFERENT_GIDS    ((gid)-1)
 #define DIFFERENT_PERMS   ((mode_t)-1)
 
-using namespace Qt::Literals::StringLiterals;
-
 namespace Fm {
 
 enum {
@@ -76,8 +73,6 @@ FilePropsDialog::FilePropsDialog(Fm::FileInfoList files, QWidget* parent, Qt::Wi
         ui->contentsLabel->hide();
         ui->fileNumber->hide();
     }
-
-    resize(size().expandedTo(sizeHint())); // make sure that the labels are shown completely (a Qt bug?)
 }
 
 FilePropsDialog::~FilePropsDialog() {
@@ -162,7 +157,7 @@ void FilePropsDialog::initPermissionsPage() {
     // Let's make it clear for the users
     // init combo boxes for file permissions here
     QStringList comboItems;
-    comboItems.append(u"---"_s); // no change
+    comboItems.append(QStringLiteral("---")); // no change
     if(singleType && hasDir) { // all files are dirs
         comboItems.append(tr("View folder content"));
         comboItems.append(tr("View and modify folder content"));
@@ -309,21 +304,21 @@ void FilePropsDialog::initGeneralPage() {
         // times
         if(fileInfo->mtime() > 0) {
             auto mtime = QDateTime::fromMSecsSinceEpoch(fileInfo->mtime() * 1000);
-            ui->lastModified->setText(locale().toString(mtime, QLocale::ShortFormat));
+            ui->lastModified->setText(mtime.toString(Qt::SystemLocaleShortDate));
         }
         else {
             ui->lastModified->setText(tr("N/A"));
         }
         if(fileInfo->atime() > 0) {
             auto atime = QDateTime::fromMSecsSinceEpoch(fileInfo->atime() * 1000);
-            ui->lastAccessed->setText(locale().toString(atime, QLocale::ShortFormat));
+            ui->lastAccessed->setText(atime.toString(Qt::SystemLocaleShortDate));
         }
         else {
             ui->lastAccessed->setText(tr("N/A"));
         }
         if(fileInfo->crtime() > 0) {
             auto crtime = QDateTime::fromMSecsSinceEpoch(fileInfo->crtime() * 1000);
-            ui->created->setText(locale().toString(crtime, QLocale::ShortFormat));
+            ui->created->setText(crtime.toString(Qt::SystemLocaleShortDate));
         }
         else {
             ui->created->setText(tr("N/A"));
@@ -406,7 +401,7 @@ void FilePropsDialog::initGeneralPage() {
             guint64 free, total;
             if(folder->getFilesystemInfo(&total, &free)) {
                 canShowDeviceUsage = true;
-                ui->progressBar->setValue(std::round(static_cast<qreal>((total - free) * 100) / static_cast<qreal>(total)));
+                ui->progressBar->setValue(qRound(static_cast<qreal>((total - free) * 100) / static_cast<qreal>(total)));
                 ui->progressBar->setFormat(tr("%p% used"));
                 ui->spaceLabel->setText(tr("%1 Free of %2")
                                         .arg(formatFileSize(free, false),
@@ -442,12 +437,12 @@ void FilePropsDialog::onFileSizeTimerTimeout() {
         // they use unsigned long instead of int.
         // We cannot use Qt here to handle plural forms. So sad. :-(
         QString str = Fm::formatFileSize(totalSizeJob->totalSize(), fm_config->si_unit) %
-                      u" (%1 B)"_s.arg(totalSizeJob->totalSize());
+                      QStringLiteral(" (%1 B)").arg(totalSizeJob->totalSize());
         // tr(" (%n) byte(s)", "", deepCountJob->total_size);
         ui->fileSize->setText(str);
 
         str = Fm::formatFileSize(totalSizeJob->totalOnDiskSize(), fm_config->si_unit) %
-              u" (%1 B)"_s.arg(totalSizeJob->totalOnDiskSize());
+              QStringLiteral(" (%1 B)").arg(totalSizeJob->totalOnDiskSize());
         // tr(" (%n) byte(s)", "", deepCountJob->total_ondisk_size);
         ui->onDiskSize->setText(str);
 
@@ -468,13 +463,13 @@ void FilePropsDialog::onIconButtonclicked() {
     QString iconDir;
     QString iconThemeName = QIcon::themeName();
     QStringList icons = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation,
-                                                  u"icons"_s,
+                                                  QStringLiteral("icons"),
                                                   QStandardPaths::LocateDirectory);
     for (QStringList::ConstIterator it = icons.constBegin(); it != icons.constEnd(); ++it) {
-        QString iconThemeFolder = *it + "/"_L1 + iconThemeName;
+        QString iconThemeFolder = *it + QLatin1String("/") + iconThemeName;
         if (QDir(iconThemeFolder).exists() && QFileInfo(iconThemeFolder).permission(QFileDevice::ReadUser)) {
             // give priority to the "places" folder
-            const QString places = iconThemeFolder + "/places"_L1;
+            const QString places = iconThemeFolder + QLatin1String("/places");
             if (QDir(places).exists() && QFileInfo(places).permission(QFileDevice::ReadUser)) {
                 iconDir = places;
             }
@@ -486,7 +481,7 @@ void FilePropsDialog::onIconButtonclicked() {
     }
     if(iconDir.isEmpty()) {
         iconDir = QStandardPaths::locate(QStandardPaths::GenericDataLocation,
-                                         u"icons"_s,
+                                         QStringLiteral("icons"),
                                          QStandardPaths::LocateDirectory);
         if(iconDir.isEmpty()) {
             return;
@@ -496,10 +491,10 @@ void FilePropsDialog::onIconButtonclicked() {
                                                           iconDir,
                                                           tr("Images (*.png *.xpm *.svg *.svgz )"));
     if(!iconPath.isEmpty()) {
-        QStringList parts = iconPath.split(u"/"_s, Qt::SkipEmptyParts);
+        QStringList parts = iconPath.split(QStringLiteral("/"), Qt::SkipEmptyParts);
         if(!parts.isEmpty()) {
             QString iconName = parts.at(parts.count() - 1);
-            int ln = iconName.lastIndexOf("."_L1);
+            int ln = iconName.lastIndexOf(QLatin1String("."));
             if(ln > -1) {
                 iconName.remove(ln, iconName.length() - ln);
                 customIcon = QIcon::fromTheme(iconName);
@@ -513,13 +508,13 @@ void FilePropsDialog::onEmblemButtonclicked() {
     QString iconDir;
     QString iconThemeName = QIcon::themeName();
     QStringList icons = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation,
-                                                  u"icons"_s,
+                                                  QStringLiteral("icons"),
                                                   QStandardPaths::LocateDirectory);
     for (QStringList::ConstIterator it = icons.constBegin(); it != icons.constEnd(); ++it) {
-        QString iconThemeFolder = *it + "/"_L1 + iconThemeName;
+        QString iconThemeFolder = *it + QLatin1String("/") + iconThemeName;
         if (QDir(iconThemeFolder).exists() && QFileInfo(iconThemeFolder).permission(QFileDevice::ReadUser)) {
             // give priority to the "emblems" folder
-            const QString emblems = iconThemeFolder + "/emblems"_L1;
+            const QString emblems = iconThemeFolder + QLatin1String("/emblems");
             if (QDir(emblems).exists() && QFileInfo(emblems).permission(QFileDevice::ReadUser)) {
                 iconDir = emblems;
             }
@@ -531,7 +526,7 @@ void FilePropsDialog::onEmblemButtonclicked() {
     }
     if(iconDir.isEmpty()) {
         iconDir = QStandardPaths::locate(QStandardPaths::GenericDataLocation,
-                                         u"icons"_s,
+                                         QStringLiteral("icons"),
                                          QStandardPaths::LocateDirectory);
         if(iconDir.isEmpty()) {
             return;
@@ -541,10 +536,10 @@ void FilePropsDialog::onEmblemButtonclicked() {
                                                           iconDir,
                                                           tr("Images (*.png *.xpm *.svg *.svgz )"));
     if(!iconPath.isEmpty()) {
-        QStringList parts = iconPath.split(u"/"_s, Qt::SkipEmptyParts);
+        QStringList parts = iconPath.split(QStringLiteral("/"), Qt::SkipEmptyParts);
         if(!parts.isEmpty()) {
             QString iconName = parts.at(parts.count() - 1);
-            int ln = iconName.lastIndexOf("."_L1);
+            int ln = iconName.lastIndexOf(QLatin1String("."));
             if(ln > -1) {
                 iconName.remove(ln, iconName.length() - ln);
                 auto emblemIcon = QIcon::fromTheme(iconName);
@@ -558,7 +553,7 @@ void FilePropsDialog::onEmblemButtonclicked() {
 }
 
 void FilePropsDialog::onClearEmblemButtonclicked() {
-    ui->emblemButton->setText(u"..."_s);
+    ui->emblemButton->setText(QStringLiteral("..."));
     // to show that the emblem should be removed
     ui->emblemButton->setIcon(QIcon());
     ui->emblemButton->setToolButtonStyle(Qt::ToolButtonTextOnly);
@@ -769,10 +764,6 @@ void FilePropsDialog::initOwner() {
         if(userId != 0) { // on local filesystems, only root can do chown.
             ui->owner->setEnabled(false);
             ui->ownerGroup->setEnabled(userId == uid);
-            ui->ownerPerm->setEnabled(userId == uid);
-            ui->groupPerm->setEnabled(userId == uid);
-            ui->otherPerm->setEnabled(userId == uid);
-            ui->executable->setEnabled(userId == uid);
         }
     }
 }
