@@ -29,7 +29,6 @@
 #include <QDebug>
 #include "customaction_p.h"
 #include "customactions/fileaction.h"
-#include <QActionGroup>
 #include <QMessageBox>
 
 namespace Fm {
@@ -78,21 +77,20 @@ FolderMenu::FolderMenu(FolderView* view, QWidget* parent):
         separator2_ = addSeparator();
     }
 
-    invertSelectionAction_ = nullptr; // kept only for backward compatibility
     auto selMode = view_->childView()->selectionMode();
     if(selMode == QAbstractItemView::SingleSelection || selMode == QAbstractItemView::NoSelection) {
         selectAllAction_ = nullptr;
-        //invertSelectionAction_ = nullptr;
+        invertSelectionAction_ = nullptr;
         separator3_ = nullptr;
     }
     else {
-        selectAllAction_ = new QAction(QIcon::fromTheme(QStringLiteral("edit-select-all")), tr("Select &All"), this);
+        selectAllAction_ = new QAction(tr("Select &All"), this);
         addAction(selectAllAction_);
         connect(selectAllAction_, &QAction::triggered, this, &FolderMenu::onSelectAllActionTriggered);
 
-        /*invertSelectionAction_ = new QAction(tr("Invert Selection"), this);
+        invertSelectionAction_ = new QAction(tr("Invert Selection"), this);
         addAction(invertSelectionAction_);
-        connect(invertSelectionAction_, &QAction::triggered, this, &FolderMenu::onInvertSelectionActionTriggered);*/
+        connect(invertSelectionAction_, &QAction::triggered, this, &FolderMenu::onInvertSelectionActionTriggered);
 
         separator3_ = addSeparator();
     }
@@ -219,12 +217,12 @@ void FolderMenu::createSortMenu() {
 
     QActionGroup* group = new QActionGroup(this);
     group->setExclusive(true);
-    actionAscending_ = new QAction(QIcon::fromTheme(QStringLiteral("view-sort-ascending")), tr("Ascending"), this);
+    actionAscending_ = new QAction(tr("Ascending"), this);
     actionAscending_->setCheckable(true);
     sortMenu_->addAction(actionAscending_);
     group->addAction(actionAscending_);
 
-    actionDescending_ = new QAction(QIcon::fromTheme(QStringLiteral("view-sort-descending")), tr("Descending"), this);
+    actionDescending_ = new QAction(tr("Descending"), this);
     actionDescending_->setCheckable(true);
     sortMenu_->addAction(actionDescending_);
     group->addAction(actionDescending_);
@@ -356,7 +354,7 @@ void FolderMenu::onHiddenLastActionTriggered(bool checked) {
 void FolderMenu::onPropertiesActionTriggered() {
     auto folderInfo = view_->folderInfo();
     if(folderInfo) {
-        FilePropsDialog::showForFile(folderInfo, view_->window());
+        FilePropsDialog::showForFile(folderInfo);
     }
 }
 
