@@ -32,7 +32,6 @@
 #include <QDebug>
 #include "pathedit.h"
 
-#include <algorithm>
 
 namespace Fm {
 
@@ -74,7 +73,7 @@ PathBar::PathBar(QWidget* parent):
     topLayout->addWidget(scrollToEnd_);
 
     // container widget of the path buttons
-    buttonsWidget_ = new QWidget;
+    buttonsWidget_ = new QWidget(this);
     buttonsWidget_->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
 
     buttonsLayout_ = new QHBoxLayout(buttonsWidget_);
@@ -86,11 +85,6 @@ PathBar::PathBar(QWidget* parent):
     // ensure the parent's background is shown behind the bar
     scrollArea_->viewport()->setAutoFillBackground(false);
     buttonsWidget_->setAutoFillBackground(false);
-
-    // for wheel scrolling over buttons (= visible widgets)
-    buttonsWidget_->installEventFilter (this);
-    scrollToStart_->installEventFilter (this);
-    scrollToEnd_->installEventFilter (this);
 }
 
 void PathBar::resizeEvent(QResizeEvent* event) {
@@ -101,13 +95,30 @@ void PathBar::resizeEvent(QResizeEvent* event) {
     }
 }
 
+void PathBar::wheelEvent(QWheelEvent* event) {
+    QWidget::wheelEvent(event);
+    QAbstractSlider::SliderAction action = QAbstractSlider::SliderNoAction;
+    int vDelta = event->angleDelta().y();
+    if(vDelta > 0) {
+        if(scrollToStart_->isEnabled()) {
+            action = QAbstractSlider::SliderSingleStepSub;
+        }
+    }
+    else if(vDelta < 0) {
+        if(scrollToEnd_->isEnabled()) {
+            action = QAbstractSlider::SliderSingleStepAdd;
+        }
+    }
+    scrollArea_->horizontalScrollBar()->triggerAction(action);
+}
+
 void PathBar::mousePressEvent(QMouseEvent* event) {
     QWidget::mousePressEvent(event);
     if(event->button() == Qt::LeftButton) {
         openEditor();
     }
     else if(event->button() == Qt::MiddleButton) {
-        PathButton* btn = qobject_cast<PathButton*>(childAt(event->position().toPoint()));
+        PathButton* btn = qobject_cast<PathButton*>(childAt(event->x(), event->y()));
         if(btn != nullptr) {
             scrollArea_->ensureWidgetVisible(btn,
                                              1); // a harmless compensation for a miscalculation in Qt
@@ -120,37 +131,15 @@ void PathBar::contextMenuEvent(QContextMenuEvent* event) {
     QMenu* menu = new QMenu(this);
     connect(menu, &QMenu::aboutToHide, menu, &QMenu::deleteLater);
 
-    QAction* action = menu->addAction(QIcon::fromTheme(QStringLiteral("edit-rename")), tr("&Edit Path"));
+    QAction* action = menu->addAction(tr("&Edit Path"));
     connect(action, &QAction::triggered, this, &PathBar::openEditor);
 
-    action = menu->addAction(QIcon::fromTheme(QStringLiteral("edit-copy")), tr("&Copy Path"));
+    action = menu->addAction(tr("&Copy Path"));
     connect(action, &QAction::triggered, this, &PathBar::copyPath);
 
     menu->popup(mapToGlobal(event->pos()));
 }
 
-bool PathBar::eventFilter(QObject* watched, QEvent* event) {
-    if(event->type() == QEvent::Wheel
-       && (watched == buttonsWidget_ || watched == scrollToStart_ || watched == scrollToEnd_)) {
-        QWheelEvent* we = static_cast<QWheelEvent*>(event);
-        QAbstractSlider::SliderAction action = QAbstractSlider::SliderNoAction;
-        int vDelta = we->angleDelta().y();
-        if(vDelta > 0) {
-            if(scrollToStart_->isEnabled()) {
-                action = QAbstractSlider::SliderSingleStepSub;
-            }
-        }
-        else if(vDelta < 0) {
-            if(scrollToEnd_->isEnabled()) {
-                action = QAbstractSlider::SliderSingleStepAdd;
-            }
-        }
-        scrollArea_->horizontalScrollBar()->triggerAction(action);
-        return true;
-    }
-    return QWidget::eventFilter(watched, event);
-}
-
 void PathBar::updateScrollButtonVisibility() {
     // Wait for the horizontal scrollbar to be completely shaped.
     // Without this, the enabled state of arrow buttons might be
@@ -174,8 +163,8 @@ void PathBar::setScrollButtonVisibility() {
         scrollToStart_->setEnabled(value != sb->minimum());
         scrollToEnd_->setEnabled(value != sb->maximum());
         // align scroll buttons horizontally
-        scrollToStart_->setMaximumHeight(std::max(buttonsWidget_->height(), scrollToStart_->minimumSizeHint().height()));
-        scrollToEnd_->setMaximumHeight(std::max(buttonsWidget_->height(), scrollToEnd_->minimumSizeHint().height()));
+        scrollToStart_->setMaximumHeight(qMax(buttonsWidget_->height(), scrollToStart_->minimumSizeHint().height()));
+        scrollToEnd_->setMaximumHeight(qMax(buttonsWidget_->height(), scrollToEnd_->minimumSizeHint().height()));
     }
 }
 
@@ -293,7 +282,7 @@ void PathBar::setPath(Fm::FilePath path) {
             name = pathStr.toStdString();
         }
         // double ampersands to distinguish them from mnemonics
-        displayName.replace(QLatin1Char('&'), QLatin1StringView("&&"));
+        displayName.replace(QLatin1Char('&'), QLatin1String("&&"));
         auto btn = new PathButton(name, displayName, isRoot, buttonsWidget_);
         btn->show();
         connect(btn, &QAbstractButton::toggled, this, &PathBar::onButtonToggled);
