@@ -23,7 +23,6 @@
 #include <QComboBox>
 #include <QVBoxLayout>
 #include <QHeaderView>
-#include <QTimer>
 #include "placesview.h"
 #include "dirtreeview.h"
 #include "dirtreemodel.h"
@@ -53,24 +52,17 @@ SidePane::~SidePane() {
     // qDebug("delete SidePane");
 }
 
-bool SidePane::eventFilter(QObject* watched, QEvent* event) {
-    // When the palette or style changes, we should set the text color of PlacesView
-    // to its window text color again because the latter may have changed.
-    if(view_ != nullptr && watched == view_
-       && (event->type() == QEvent::PaletteChange || event->type() == QEvent::StyleChange)
-       && mode_ == ModePlaces) {
-        QTimer::singleShot(0, this, [this]() {
-            if(PlacesView* placesView = static_cast<PlacesView*>(view_)) {
-                QPalette p = placesView->palette();
-                if(p.color(QPalette::Text) != p.color(QPalette::WindowText)) {
-                    p.setColor(QPalette::Active, QPalette::Text, p.color(QPalette::Active, QPalette::WindowText));
-                    p.setColor(QPalette::Inactive, QPalette::Text, p.color(QPalette::Inactive, QPalette::WindowText));
-                    placesView->setPalette(p);
-                }
-            }
-        });
+bool SidePane::event(QEvent* event) {
+    // when the SidePane's style changes, we should set the text color of
+    // PlacesView to its window text color again because the latter may have changed
+    if(event->type() == QEvent::StyleChange && mode_ == ModePlaces) {
+        if(PlacesView* placesView = static_cast<PlacesView*>(view_)) {
+            QPalette p = placesView->palette();
+            p.setColor(QPalette::Text, p.color(QPalette::WindowText));
+            placesView->setPalette(p);
+        }
     }
-    return QWidget::eventFilter(watched, event);
+    return QWidget::event(event);
 }
 
 void SidePane::onComboCurrentIndexChanged(int current) {
@@ -191,8 +183,7 @@ void SidePane::setMode(Mode mode) {
         placesView->setFrameShape(QFrame::NoFrame);
         QPalette p = placesView->palette();
         p.setColor(QPalette::Base, QColor(Qt::transparent));
-        p.setColor(QPalette::Active, QPalette::Text, p.color(QPalette::Active, QPalette::WindowText));
-        p.setColor(QPalette::Inactive, QPalette::Text, p.color(QPalette::Inactive, QPalette::WindowText));
+        p.setColor(QPalette::Text, p.color(QPalette::WindowText));
         placesView->setPalette(p);
         placesView->viewport()->setAutoFillBackground(false);
 
@@ -202,7 +193,6 @@ void SidePane::setMode(Mode mode) {
         placesView->setCurrentPath(currentPath_);
         connect(placesView, &PlacesView::chdirRequested, this, &SidePane::chdirRequested);
         connect(placesView, &PlacesView::hiddenItemSet, this, &SidePane::hiddenPlaceSet);
-        view_->installEventFilter(this); // for setting text color after palette change
         break;
     }
     case ModeDirTree: {
