@@ -260,7 +260,7 @@ _retry:
         // text entry
         QLineEdit *le = new QLineEdit(defaultNewName);
         int length = defaultNewName.lastIndexOf(QStringLiteral("."));
-        if(length > 0 && length < defaultNewName.size() - 1) {
+        if(length > -1) {
             le->setSelection(0, length);
         }
         else {
@@ -277,7 +277,6 @@ _retry:
         layout->addWidget(btns);
         dlg.setLayout(layout);
         dlg.setMaximumHeight(dlg.minimumSizeHint().height()); // no vertical resizing
-        le->setFocus(); // needed with Qt >= 6.6.1
 
         switch (dlg.exec()) {
         case QDialog::Accepted:
