@@ -21,6 +21,7 @@
 #include "xdndworkaround.h"
 #include <QApplication>
 #include <QDebug>
+#include <QX11Info>
 #include <QMimeData>
 #include <QCursor>
 #include <QWidget>
@@ -40,11 +41,7 @@
 
 
 XdndWorkaround::XdndWorkaround() {
-    if(qApp->platformName() != QStringLiteral("xcb")) {
-        return;
-    }
-    auto x11NativeInterface = qApp->nativeInterface<QNativeInterface::QX11Application>();
-    if(!x11NativeInterface) {
+    if(!QX11Info::isPlatformX11()) {
         return;
     }
 
@@ -59,7 +56,7 @@ XdndWorkaround::XdndWorkaround() {
 
     // initialize xinput2 since newer versions of Qt5 uses it.
     static char xi_name[] = "XInputExtension";
-    xcb_connection_t* conn = x11NativeInterface->connection();
+    xcb_connection_t* conn = QX11Info::connection();
     xcb_query_extension_cookie_t cookie = xcb_query_extension(conn, strlen(xi_name), xi_name);
     xcb_generic_error_t* err = nullptr;
     xcb_query_extension_reply_t* reply = xcb_query_extension_reply(conn, cookie, &err);
@@ -81,13 +78,13 @@ XdndWorkaround::XdndWorkaround() {
 }
 
 XdndWorkaround::~XdndWorkaround() {
-    if(qApp->platformName() != QStringLiteral("xcb")) {
+    if(!QX11Info::isPlatformX11()) {
         return;
     }
     qApp->removeNativeEventFilter(this);
 }
 
-bool XdndWorkaround::nativeEventFilter(const QByteArray& eventType, void* message, qintptr* /*result*/) {
+bool XdndWorkaround::nativeEventFilter(const QByteArray& eventType, void* message, long* /*result*/) {
     if(Q_LIKELY(eventType == "xcb_generic_event_t")) {
         xcb_generic_event_t* event = static_cast<xcb_generic_event_t*>(message);
         switch(event->response_type & ~0x80) {
@@ -114,18 +111,15 @@ bool XdndWorkaround::nativeEventFilter(const QByteArray& eventType, void* messag
 // static
 QByteArray XdndWorkaround::atomName(xcb_atom_t atom) {
     QByteArray name;
-    auto x11NativeInterface = qApp->nativeInterface<QNativeInterface::QX11Application>();
-    if(x11NativeInterface) {
-        xcb_connection_t* conn = x11NativeInterface->connection();
-        xcb_get_atom_name_cookie_t cookie = xcb_get_atom_name(conn, atom);
-        xcb_get_atom_name_reply_t* reply = xcb_get_atom_name_reply(conn, cookie, nullptr);
-        if(reply != nullptr) {
-            int len = xcb_get_atom_name_name_length(reply);
-            if(len > 0) {
-                name.append(xcb_get_atom_name_name(reply), len);
-            }
-            free(reply);
+    xcb_connection_t* conn = QX11Info::connection();
+    xcb_get_atom_name_cookie_t cookie = xcb_get_atom_name(conn, atom);
+    xcb_get_atom_name_reply_t* reply = xcb_get_atom_name_reply(conn, cookie, nullptr);
+    if(reply != nullptr) {
+        int len = xcb_get_atom_name_name_length(reply);
+        if(len > 0) {
+            name.append(xcb_get_atom_name_name(reply), len);
         }
+        free(reply);
     }
     return name;
 }
@@ -133,22 +127,19 @@ QByteArray XdndWorkaround::atomName(xcb_atom_t atom) {
 // static
 xcb_atom_t XdndWorkaround::internAtom(const char* name, int len) {
     xcb_atom_t atom = 0;
-    auto x11NativeInterface = qApp->nativeInterface<QNativeInterface::QX11Application>();
-    if(x11NativeInterface) {
-        if(len == -1) {
-            len = strlen(name);
-        }
-        xcb_connection_t* conn = x11NativeInterface->connection();
-        xcb_intern_atom_cookie_t cookie = xcb_intern_atom(conn, false, len, name);
-        xcb_generic_error_t* err = nullptr;
-        xcb_intern_atom_reply_t* reply = xcb_intern_atom_reply(conn, cookie, &err);
-        if(reply != nullptr) {
-            atom = reply->atom;
-            free(reply);
-        }
-        if(err != nullptr) {
-            free(err);
-        }
+    if(len == -1) {
+        len = strlen(name);
+    }
+    xcb_connection_t* conn = QX11Info::connection();
+    xcb_intern_atom_cookie_t cookie = xcb_intern_atom(conn, false, len, name);
+    xcb_generic_error_t* err = nullptr;
+    xcb_intern_atom_reply_t* reply = xcb_intern_atom_reply(conn, cookie, &err);
+    if(reply != nullptr) {
+        atom = reply->atom;
+        free(reply);
+    }
+    if(err != nullptr) {
+        free(err);
     }
     return atom;
 }
@@ -156,32 +147,26 @@ xcb_atom_t XdndWorkaround::internAtom(const char* name, int len) {
 // static
 QByteArray XdndWorkaround::windowProperty(xcb_window_t window, xcb_atom_t propAtom, xcb_atom_t typeAtom, int len) {
     QByteArray data;
-    auto x11NativeInterface = qApp->nativeInterface<QNativeInterface::QX11Application>();
-    if(x11NativeInterface) {
-        xcb_connection_t* conn = x11NativeInterface->connection();
-        xcb_get_property_cookie_t cookie = xcb_get_property(conn, false, window, propAtom, typeAtom, 0, len);
-        xcb_generic_error_t* err = nullptr;
-        xcb_get_property_reply_t* reply = xcb_get_property_reply(conn, cookie, &err);
-        if(reply != nullptr) {
-            len = xcb_get_property_value_length(reply);
-            const char* buf = (const char*)xcb_get_property_value(reply);
-            data.append(buf, len);
-            free(reply);
-        }
-        if(err != nullptr) {
-            free(err);
-        }
+    xcb_connection_t* conn = QX11Info::connection();
+    xcb_get_property_cookie_t cookie = xcb_get_property(conn, false, window, propAtom, typeAtom, 0, len);
+    xcb_generic_error_t* err = nullptr;
+    xcb_get_property_reply_t* reply = xcb_get_property_reply(conn, cookie, &err);
+    if(reply != nullptr) {
+        len = xcb_get_property_value_length(reply);
+        const char* buf = (const char*)xcb_get_property_value(reply);
+        data.append(buf, len);
+        free(reply);
+    }
+    if(err != nullptr) {
+        free(err);
     }
     return data;
 }
 
 // static
 void XdndWorkaround::setWindowProperty(xcb_window_t window, xcb_atom_t propAtom, xcb_atom_t typeAtom, void* data, int len, int format) {
-    auto x11NativeInterface = qApp->nativeInterface<QNativeInterface::QX11Application>();
-    if(x11NativeInterface) {
-        xcb_connection_t* conn = x11NativeInterface->connection();
-        xcb_change_property(conn, XCB_PROP_MODE_REPLACE, window, propAtom, typeAtom, format, len, data);
-    }
+    xcb_connection_t* conn = QX11Info::connection();
+    xcb_change_property(conn, XCB_PROP_MODE_REPLACE, window, propAtom, typeAtom, format, len, data);
 }
 
 
@@ -233,11 +218,7 @@ bool XdndWorkaround::selectionNotify(xcb_selection_notify_event_t* event) {
 
 
 bool XdndWorkaround::selectionRequest(xcb_selection_request_event_t* event) {
-    auto x11NativeInterface = qApp->nativeInterface<QNativeInterface::QX11Application>();
-    if(!x11NativeInterface) {
-        return false;
-    }
-    xcb_connection_t* conn = x11NativeInterface->connection();
+    xcb_connection_t* conn = QX11Info::connection();
     if(event->property == XCB_ATOM_PRIMARY || event->property == XCB_ATOM_SECONDARY) {
         return false;    // we only touch selection requests related to XDnd
     }
